@@ -12,8 +12,8 @@ class StoryArc:
 class StoryArcSchema(Schema):
     aliases = fields.Str(allow_none=True)
     api_url = fields.Url(data_key="api_detail_url")
-    date_added = fields.DateTime(format="%Y-%m-%d %H:%M:%S")
-    date_last_updated = fields.DateTime(format="%Y-%m-%d %H:%M:%S")
+    date_added = fields.DateTime()
+    date_last_updated = fields.DateTime()
     description = fields.Str(allow_none=True)
     # Ignoring Episodes
     # Ignoring First Episode
@@ -30,6 +30,7 @@ class StoryArcSchema(Schema):
 
     class Meta:
         unknown = EXCLUDE
+        dateformat = "%Y-%m-%d %H:%M:%S"
 
     @post_load
     def make_object(self, data, **kwargs) -> StoryArc:
